@@ -1,21 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004-2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -48,7 +48,7 @@ _WP3ContentParsingState::~_WP3ContentParsingState()
 	DELETEP(m_cellFillColor);
 }
 
-WP3ContentListener::WP3ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP3SubDocument *>&subDocuments, WPXDocumentInterface *documentInterface) :
+WP3ContentListener::WP3ContentListener(std::list<WPXPageSpan> &pageList, std::vector<WP3SubDocument *> &subDocuments, WPXDocumentInterface *documentInterface) :
 	WP3Listener(),
 	WPXContentListener(pageList, documentInterface),
 	m_parseState(new WP3ContentParsingState),
@@ -83,8 +83,8 @@ void WP3ContentListener::insertTab()
 	{
 		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
 		{
-			if (m_ps->m_tabStops.empty() || (_getNextTabStop() == (std::numeric_limits<double>::max)()))
-				m_ps->m_textIndentByTabs += 0.5f;
+			if (m_ps->m_tabStops.empty())
+				m_ps->m_textIndentByTabs += 0.5;
 			else
 				m_ps->m_textIndentByTabs = _getNextTabStop() - (m_ps->m_leftMarginByTabs  + m_ps->m_textIndentByParagraphIndentChange);
 			m_ps->m_paragraphTextIndent = m_ps->m_textIndentByParagraphIndentChange
@@ -375,6 +375,8 @@ void WP3ContentListener::attributeChange(const bool isOn, const uint8_t attribut
 		case WP3_ATTRIBUTE_SMALL_CAPS:
 			textAttributeBit = WPX_SMALL_CAPS_BIT;
 			break;
+		default:
+			break;
 		}
 
 		if (isOn)
@@ -431,6 +433,8 @@ void WP3ContentListener::marginChange(const uint8_t side, const uint16_t margin)
 			                               + m_ps->m_rightMarginByParagraphMarginChange
 			                               + m_ps->m_rightMarginByTabs;
 			break;
+		default:
+			break;
 		}
 		m_ps->m_listReferencePosition = m_ps->m_paragraphMarginLeft + m_ps->m_paragraphTextIndent;
 	}
@@ -444,9 +448,6 @@ void WP3ContentListener::justificationChange(const uint8_t justification)
 		// m_ps->m_paragraphJustification = justification;
 		switch (justification)
 		{
-		case 0x00:
-			m_ps->m_paragraphJustification = WPX_PARAGRAPH_JUSTIFICATION_LEFT;
-			break;
 		case 0x01:
 			m_ps->m_paragraphJustification = WPX_PARAGRAPH_JUSTIFICATION_CENTER;
 			break;
@@ -462,16 +463,18 @@ void WP3ContentListener::justificationChange(const uint8_t justification)
 		case 0x05:
 			m_ps->m_paragraphJustification = WPX_PARAGRAPH_JUSTIFICATION_DECIMAL_ALIGNED;
 			break;
+		default:  // case 0x00 and all other invalid things
+			m_ps->m_paragraphJustification = WPX_PARAGRAPH_JUSTIFICATION_LEFT;
+			break;
 		}
 	}
 }
 
-void WP3ContentListener::indentFirstLineChange(const int16_t offset)
+void WP3ContentListener::indentFirstLineChange(double offset)
 {
 	if (!isUndoOn())
 	{
-		double offsetInch = (double)((double)offset / (double)WPX_NUM_WPUS_PER_INCH);
-		m_ps->m_textIndentByParagraphIndentChange = offsetInch;
+		m_ps->m_textIndentByParagraphIndentChange = offset;
 		// This is necessary in case we have Indent First Line and Hard Back Tab
 		// in the same time. The Hard Back Tab applies to the current paragraph
 		// only. Indent First Line applies untill an new Indent First Line code.
@@ -497,7 +500,7 @@ void WP3ContentListener::columnChange(const WPXTextColumnType /* columnType */,
 	{
 		_openPageSpan();
 
-		int oldColumnNum = m_ps->m_numColumns;
+		unsigned oldColumnNum = m_ps->m_numColumns;
 
 		// In WP, the last column ends with a hard column break code.
 		// In this case, we do not really want to insert any column break
@@ -512,8 +515,8 @@ void WP3ContentListener::columnChange(const WPXTextColumnType /* columnType */,
 		tmpColumnDefinition.clear();
 		if (numColumns > 1)
 		{
-			int i;
-			for (i=0; i<(int)columnWidth.size(); i++)
+			unsigned i;
+			for (i=0; i<columnWidth.size(); i++)
 			{
 				if (isFixedWidth[i])
 					remainingSpace -= columnWidth[i];
@@ -528,7 +531,7 @@ void WP3ContentListener::columnChange(const WPXTextColumnType /* columnType */,
 				else
 					tmpColumn.m_leftGutter = 0.5f * remainingSpace * columnWidth[2*i-1];
 
-				if (i >= (numColumns - 1))
+				if (i >= (unsigned)(numColumns - 1))
 					tmpColumn.m_rightGutter = 0.0;
 				else if (isFixedWidth[2*i+1])
 					tmpColumn.m_rightGutter = 0.5f * columnWidth[2*i+1];
@@ -654,7 +657,7 @@ void WP3ContentListener::backTab()
 {
 	if (!isUndoOn() && !m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
 	{
-		if (m_ps->m_tabStops.empty() || (_getPreviousTabStop() == (std::numeric_limits<double>::max)()))
+		if (m_ps->m_tabStops.empty())
 			m_ps->m_textIndentByTabs -= 0.5f;
 		else
 			m_ps->m_textIndentByTabs = _getPreviousTabStop() - (m_ps->m_leftMarginByTabs  + m_ps->m_textIndentByParagraphIndentChange);
@@ -676,7 +679,7 @@ void WP3ContentListener::leftIndent()
 	{
 		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
 		{
-			if (m_ps->m_tabStops.empty() || (_getNextTabStop() == (std::numeric_limits<double>::min)()))
+			if (m_ps->m_tabStops.empty())
 				m_ps->m_leftMarginByTabs += 0.5f;
 			else
 				m_ps->m_leftMarginByTabs = _getNextTabStop() - (m_ps->m_textIndentByTabs + m_ps->m_textIndentByParagraphIndentChange);
@@ -732,7 +735,7 @@ void WP3ContentListener::leftRightIndent()
 	{
 		if (!m_ps->m_isParagraphOpened && !m_ps->m_isListElementOpened)
 		{
-			if (m_ps->m_tabStops.empty() || (_getNextTabStop() == (std::numeric_limits<double>::min)()))
+			if (m_ps->m_tabStops.empty())
 				m_ps->m_leftMarginByTabs += 0.5f;
 			else
 				m_ps->m_leftMarginByTabs = _getNextTabStop() - (m_ps->m_textIndentByTabs + m_ps->m_textIndentByParagraphIndentChange);
@@ -1110,7 +1113,7 @@ void WP3ContentListener::_handleFrameParameters( WPXPropertyList &propList, doub
 }
 
 void WP3ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType,
-        WPXTableList /* tableList */, int /* nextTableIndice */)
+        WPXTableList /* tableList */, unsigned /* nextTableIndice */)
 {
 	// save our old parsing state on our "stack"
 	WP3ContentParsingState *oldParseState = m_parseState;
